export function rewriteCookieDomain(cookie: string, domainRewrite: string | Record<string, string>) {
  if (!domainRewrite) return cookie;

  // 解析 Cookie 的属性
  const parts = cookie.split(';').map((part) => part.trim());
  const nameValue = parts[0];
  const attributes = parts.slice(1);

  // 查找并替换 Domain 属性
  const newAttributes = attributes.map((attr) => {
    if (attr.startsWith('Domain=')) {
      const originalDomain = attr.slice(7); // 去掉 "Domain="
      let newDomain = domainRewrite;

      // 如果 domainRewrite 是对象，根据映射关系替换
      if (typeof domainRewrite === 'object') {
        newDomain = domainRewrite[originalDomain] || originalDomain;
      }

      return `Domain=${newDomain}`;
    }
    return attr;
  });

  // 重新组合 Cookie
  return [nameValue, ...newAttributes].join('; ');
}
