export class Logger {
  level: string;
  constructor(level: string) {
    this.level = level;
  }
  info(message: string, data?: any, ...args: any[]) {
    if (this.level === 'info') {
      console.log(`INFO: ${message}`, data, ...args);
    }
  }
  error(message: string, data?: any, ...args: any[]) {
    if (this.level === 'error') {
      console.error(`ERROR: ${message}`, data, ...args);
    }
  }
  warn(message: string, data?: any, ...args: any[]) {
    if (this.level === 'warn') {
      console.warn(`WARN: ${message}`, data, ...args);
    }
  }
  debug(message: string, data?: any, ...args: any[]) {
    if (this.level === 'debug') {
      console.debug(`DEBUG: ${message}`, data, ...args);
    }
  }
  log(message: string, ...args: any[]) {
    if (this.level === 'log') {
      console.log(`LOG: ${message}`, ...args);
    }
  }
}
const logger = new Logger(process.env.LOG_LEVEL || 'info');

export const console = {
  log: logger.info,
  error: logger.error,
  warn: logger.warn,
  info: logger.info,
  debug: logger.debug,
};

export const logError = (message: string, data?: any) => logger.error(data, message);
export const logWarning = (message: string, data?: any) => logger.warn(data, message);
export const logInfo = (message: string, data?: any) => logger.info(data, message);
export const logDebug = (message: string, data?: any) => logger.debug(data, message);

export const log = {
  log: logInfo,
  error: logError,
  warn: logWarning,
  info: logInfo,
  debug: logDebug,
};
